openesm-package: openesm: Access the Open Experience Sampling Method Database

openesm-packageR Documentation

openesm: Access the Open Experience Sampling Method Database

Description

Provides programmatic access to the Open Experience Sampling Method ('openESM') database (https://openesmdata.org), a collection of harmonized experience sampling datasets. The package enables researchers to discover, download, and work with the datasets while ensuring proper citation and license compliance.

Author(s)

Maintainer: Björn S. Siepe bjoernsiepe@gmail.com (ORCID) [copyright holder]

Authors:

See Also

Useful links:


openesm documentation built on Dec. 3, 2025, 5:08 p.m.